# Nicotine+ Translators

## English
- mathiascode (2020)
- Michael Labouebe (2016) [gfarmerfr(at)free(dot)fr]
- hyriand
- daelstorm

## Dutch
- nince78 (2007)
- hyriand

## German
- Meokater (2007)
- (.\_.) (2007)
- lippel (2004)
- hyriand (2003)

## Spanish
- Silvio Orta (2007)
- Dreslo

## French
- m-balthazar (2020)
- Michael Labouebe (2016-2017) [gfarmerfr(at)free(dot)fr]
- ManWell (2007)
- zniavre (2007)
- flashfr
- systr

## Italian
- Gianluca Boiano
- Nicola (2007) [info(at)nicoladimaria(dot)info]
- dbazza

## Polish
- Amun-Ra (2007)
- thine (2007)
- owczi

## Swedish
- mitramai (2021)
- alimony [markus(at)samsonrourke(dot)com]

## Hungarian
- djbaloo [dj_baloo(at)freemail(dot)hu]

## Slovak
- Josef Riha (2006) [jose1711(at)gmail(dot)com]

## Portuguese Brazilian
- yyyyyyyan (2020)
- Suicide\|Solution (2006) [felipe(at)bunghole(dot)com(dot)br]

## Lithuanian
- Žygimantas (2006) [uid0(at)akl(dot)lt]

## Finnish
- Kalevi [mr_auer(at)welho(dot)net]

## Euskara
- The Librezale.org Team [librezale(at)librezale(dot)org]
